Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/client/video.h')
-rw-r--r--src/client/video.h11
1 files changed, 4 insertions, 7 deletions
diff --git a/src/client/video.h b/src/client/video.h
index daa136c..a28b17d 100644
--- a/src/client/video.h
+++ b/src/client/video.h
@@ -24,14 +24,11 @@ namespace video
*/
void restart();
- /// draw the next client video frame
- void frame(float seconds);
-
- /// width of the application window in pixels
- extern int width;
+ /// application window resize event in windowed mode
+ void resize(float w, float h);
- /// height of the application window in pixels
- extern int height;
+ /// draw the next client video frame
+ void frame(float elapsed);
} // namespace video